<!--

#################################################
### THIS FILE WAS AUTOGENERATED! DO NOT EDIT! ###
#################################################
# file to edit: 99_index.ipynb
# command to build the docs after a change: nbdev_build_docs

-->

# Lngen : Line generation

> Summary description here: just testing nbdev for the moment

<div class="codecell" markdown="1">
<div class="input_area" markdown="1">

```python
!find / -name *nbdev*
```

</div>
<div class="output_area" markdown="1">

    find: ‘/tmp/tmpiga82kvw_kernels’: Permission denied
    find: ‘/var/cache/apt/archives/partial’: Permission denied
    find: ‘/var/cache/ldconfig’: Permission denied
    find: ‘/var/lib/apt/lists/partial’: Permission denied
    find: ‘/proc/tty/driver’: Permission denied
    find: ‘/etc/ssl/private’: Permission denied
    find: ‘/root’: Permission denied


</div>

</div>

This file will become your README and also the index of your documentation.

## Install

`pip install lngen`

## How to use

Fill me in please! Don't forget code examples:
<div class="codecell" markdown="1">
<div class="input_area" markdown="1">

```python
1+1
```

</div>
<div class="output_area" markdown="1">




    2



</div>

</div>
